{ inputs, pkgs, config, lib, ... }: {
  imports = [
    ../../templates/proxmox-lxc.nix
    ../../server.nix
  ];

  networking.hostName = "live-doll-repair";
  system.stateVersion = "24.05";
  nixpkgs.hostPlatform = "x86_64-linux";

  services.nginx = {
    enable = true;
    additionalModules = [
      pkgs.nginxModules.rtmp
    ];

    virtualHosts."live.doll.repair" = {
      locations."/" = {
        root = pkgs.writeTextDir "index.html" ''
          <!doctype html>
          <link href="https://vjs.zencdn.net/8.10.0/video-js.css" rel="stylesheet" />
          <style>:root {margin: 0; padding: 0;} video { width: 100vw; height: 100vh; }</style>
          <!-- Or if you want the latest version from the main branch -->
          <!-- <script src="https://cdn.jsdelivr.net/npm/hls.js@canary"></script> -->
          <video id="video" class="video-js" preload="auto" controls autoplay muted data-setup='{"liveui": true, "autoplay": "play", "fluid": true, "liveTracker": { "liveTolerance": 5 }}'>
            <source src="https://live.doll.repair/stream/meow.m3u8">
            <source src="https://live.doll.repair/stream-dash/meow.mpd">
          </video>
          <script src="https://vjs.zencdn.net/8.10.0/video.min.js"></script>
          <script>
            window.HELP_IMPROVE_VIDEOJS = false;
          </script>
        '';
      };

      locations."/stream" = {
        root = "/tmp";
        extraConfig = ''
          autoindex on;
          add_header Cache-Control no-cache;
          types {
            application/vnd.apple.mpegurl m3u8;
            video/mp2t ts;
            application/dash+xml mpd;
          }
        '';
      };
      locations."/stream-dash" = {
        root = "/tmp";
        extraConfig = ''
          autoindex on;
          add_header Cache-Control no-cache;
          types {
            application/vnd.apple.mpegurl m3u8;
            video/mp2t ts;
            application/dash+xml mpd;
          }
        '';
      };
    };

    appendConfig = ''
      rtmp {
        server {
          listen 1935;
          chunk_size 4096;

          application live {
            live on;

            allow publish 100.64.0.0/10;
            deny publish all;
            deny play all;

            hls on;
            hls_path /tmp/stream;
            hls_playlist_length 2s;
            hls_fragment 1s;
            hls_continuous on;

            dash on;
            dash_path /tmp/stream-dash;
          }
        }
      }
    '';
  };
}
